ProtocolMessage class

Constructors

ProtocolMessage({required ProtocolMessageHeaders headers, required Uint8List payload, required Uint8List raw})

Properties

hashCode int
The hash code for this object.
no setterinherited
headers ProtocolMessageHeaders
final
isCompressed bool
no setter
opcode int
no setter
payload Uint8List
final
raw Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId int
no setter
trackId int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited