Action class

Constructors

Action({String description = '', String actionId = ''})
Action.fromJson(Map<String, dynamic> json)
factory
Action.fromReader(TeleportObjectReader reader)
factory
Action.fromTeleport(Uint8List data)
factory

Properties

actionId ↔ String
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toTeleport() → Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fieldIdActionId → const int
fieldIdDescription → const int
teleportVersion → const int