ActionActive class

Constructors

ActionActive({String description = '', bool isFinished = false})
ActionActive.fromJson(Map<String, dynamic> json)
factory
ActionActive.fromReader(TeleportObjectReader reader)
factory
ActionActive.fromTeleport(Uint8List data)
factory

Properties

description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isFinished bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdDescription → const int
fieldIdIsFinished → const int
teleportOpcode → const int
teleportVersion → const int