ActionCall2 class

Constructors

ActionCall2({String actionId = '', String payloadJson = '', String callId = ''})
ActionCall2.fromJson(Map<String, dynamic> json)
factory
ActionCall2.fromReader(TeleportObjectReader reader)
factory
ActionCall2.fromTeleport(Uint8List data)
factory

Properties

actionId ↔ String
getter/setter pair
callId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payloadJson ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toProtocolMessage(int senderId, {ProtocolMessageOverrides? overrides}) → ProtocolMessage
toString() → String
A string representation of this object.
inherited
toTeleport() → Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fieldIdActionId → const int
fieldIdCallId → const int
fieldIdPayloadJson → const int
teleportOpcode → const int
teleportVersion → const int