ActionClassificationResult class
Constructors
-
ActionClassificationResult({bool isFlagged = false, List<
ActionClassificationDetail> details = const []}) -
ActionClassificationResult.fromJson(Map<
String, dynamic> json) -
factory
- ActionClassificationResult.fromReader(TeleportObjectReader reader)
-
factory
- ActionClassificationResult.fromTeleport(Uint8List data)
-
factory
Properties
-
details
↔ List<
ActionClassificationDetail> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFlagged ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdDetails → const int
- fieldIdIsFlagged → const int
- teleportOpcode → const int
- teleportVersion → const int