ActionFileUploadCallback class

Constructors

ActionFileUploadCallback({String actionId = '', String fileName = '', String mime = '', int size = 0, String filePath = ''})
ActionFileUploadCallback.fromJson(Map<String, dynamic> json)
factory
ActionFileUploadCallback.fromReader(TeleportObjectReader reader)
factory
ActionFileUploadCallback.fromTeleport(Uint8List data)
factory

Properties

actionId String
getter/setter pair
fileName String
getter/setter pair
filePath String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mime String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdActionId → const int
fieldIdFileName → const int
fieldIdFilePath → const int
fieldIdMime → const int
fieldIdSize → const int
teleportOpcode → const int
teleportVersion → const int