ActionFileUploadData class

Constructors

ActionFileUploadData({String actionId = '', List<int> data = const [], int sequenceId = 0})
ActionFileUploadData.fromJson(Map<String, dynamic> json)
factory
ActionFileUploadData.fromReader(TeleportObjectReader reader)
factory
ActionFileUploadData.fromTeleport(Uint8List data)
factory

Properties

actionId String
getter/setter pair
data List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdActionId → const int
fieldIdData → const int
fieldIdSequenceId → const int
teleportOpcode → const int
teleportVersion → const int