ActionFileUploadResult class
Constructors
- ActionFileUploadResult({String actionId = '', bool isSuccess = false, String errorMessage = ''})
-
ActionFileUploadResult.fromJson(Map<
String, dynamic> json) -
factory
- ActionFileUploadResult.fromReader(TeleportObjectReader reader)
-
factory
- ActionFileUploadResult.fromTeleport(Uint8List data)
-
factory
Properties
- actionId ↔ String
-
getter/setter pair
- errorMessage ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdActionId → const int
- fieldIdErrorMessage → const int
- fieldIdIsSuccess → const int
- teleportOpcode → const int
- teleportVersion → const int