ActionOpenChannel class

Constructors

ActionOpenChannel({String channelCode = '', String prompt = ''})
ActionOpenChannel.fromJson(Map<String, dynamic> json)
factory
ActionOpenChannel.fromReader(TeleportObjectReader reader)
factory
ActionOpenChannel.fromTeleport(Uint8List data)
factory

Properties

channelCode String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
prompt String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdChannelCode → const int
fieldIdPrompt → const int
teleportOpcode → const int
teleportVersion → const int