ActionPan class

Constructors

ActionPan({Coordinate2D? location, Coordinate2D? delta})
ActionPan.fromJson(Map<String, dynamic> json)
factory
ActionPan.fromReader(TeleportObjectReader reader)
factory
ActionPan.fromTeleport(Uint8List data)
factory

Properties

delta Coordinate2D?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location Coordinate2D?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdDelta → const int
fieldIdLocation → const int
teleportOpcode → const int
teleportVersion → const int