ActionStopSound class

Constructors

ActionStopSound({String id = '', double fadeoutTimeInSec = 0.0})
ActionStopSound.fromJson(Map<String, dynamic> json)
factory
ActionStopSound.fromReader(TeleportObjectReader reader)
factory
ActionStopSound.fromTeleport(Uint8List data)
factory

Properties

fadeoutTimeInSec double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdFadeoutTimeInSec → const int
fieldIdId → const int
teleportOpcode → const int
teleportVersion → const int