ActionUIUpdateTextDelta class

Constructors

ActionUIUpdateTextDelta({String containerId = '', int elementId = 0, String delta = ''})
ActionUIUpdateTextDelta.fromJson(Map<String, dynamic> json)
factory
ActionUIUpdateTextDelta.fromReader(TeleportObjectReader reader)
factory
ActionUIUpdateTextDelta.fromTeleport(Uint8List data)
factory

Properties

containerId String
getter/setter pair
delta String
getter/setter pair
elementId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdContainerId → const int
fieldIdDelta → const int
fieldIdElementId → const int
teleportOpcode → const int
teleportVersion → const int