ActionUpdateGfxShader class

Constructors

ActionUpdateGfxShader({String name = '', double fps = 0.0, String content = '', String contentHash = ''})
ActionUpdateGfxShader.fromJson(Map<String, dynamic> json)
factory
ActionUpdateGfxShader.fromReader(TeleportObjectReader reader)
factory
ActionUpdateGfxShader.fromTeleport(Uint8List data)
factory

Properties

content String
getter/setter pair
contentHash String
getter/setter pair
fps double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdContent → const int
fieldIdContentHash → const int
fieldIdFps → const int
fieldIdName → const int
teleportOpcode → const int
teleportVersion → const int