ActionZoom class
Constructors
- ActionZoom({double startScale = 0.0, double currentScale = 0.0})
-
ActionZoom.fromJson(Map<
String, dynamic> json) -
factory
- ActionZoom.fromReader(TeleportObjectReader reader)
-
factory
- ActionZoom.fromTeleport(Uint8List data)
-
factory
Properties
- currentScale ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startScale ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdCurrentScale → const int
- fieldIdStartScale → const int
- teleportOpcode → const int
- teleportVersion → const int