Coordinate2D class

Constructors

Coordinate2D({double x = 0.0, double y = 0.0})
Coordinate2D.fromJson(Map<String, dynamic> json)
factory
Coordinate2D.fromReader(TeleportObjectReader reader)
factory
Coordinate2D.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
getter/setter pair
y double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdX → const int
fieldIdY → const int
teleportVersion → const int