AnalyticsIkonHostServerStats class
Constructors
- AnalyticsIkonHostServerStats({String time = '', String state = '', String stateReason = '', int slotCount = 0, int activeCount = 0, double cpuUsagePercentage = 0.0, double processMemoryUsedMb = 0.0, double managedMemoryUsedMb = 0.0, String memoryInfo = ''})
-
AnalyticsIkonHostServerStats.fromJson(Map<
String, dynamic> json) -
factory
- AnalyticsIkonHostServerStats.fromReader(TeleportObjectReader reader)
-
factory
- AnalyticsIkonHostServerStats.fromTeleport(Uint8List data)
-
factory
Properties
- activeCount ↔ int
-
getter/setter pair
- cpuUsagePercentage ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- managedMemoryUsedMb ↔ double
-
getter/setter pair
- memoryInfo ↔ String
-
getter/setter pair
- processMemoryUsedMb ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotCount ↔ int
-
getter/setter pair
- state ↔ String
-
getter/setter pair
- stateReason ↔ String
-
getter/setter pair
- time ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toProtocolMessage(
int senderId, {ProtocolMessageOverrides? overrides}) → ProtocolMessage -
toString(
) → String -
A string representation of this object.
inherited
-
toTeleport(
) → Uint8List -
writeTo(
TeleportObjectWriter scope) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdActiveCount → const int
- fieldIdCpuUsagePercentage → const int
- fieldIdManagedMemoryUsedMb → const int
- fieldIdMemoryInfo → const int
- fieldIdProcessMemoryUsedMb → const int
- fieldIdSlotCount → const int
- fieldIdState → const int
- fieldIdStateReason → const int
- fieldIdTime → const int
- teleportOpcode → const int
- teleportVersion → const int