AnalyticsIkonProxyServerStats class
Constructors
- AnalyticsIkonProxyServerStats({String time = '', int channelCount = 0, double sentMessagesPerSecond = 0.0, double sentMessagesBandwidthKb = 0.0, int sentMessagesCount = 0, double receivedMessagesPerSecond = 0.0, double receivedMessagesBandwidthKb = 0.0, int receivedMessagesCount = 0, double cpuUsagePercentage = 0.0, double processMemoryUsedMb = 0.0, double managedMemoryUsedMb = 0.0, String memoryInfo = ''})
-
AnalyticsIkonProxyServerStats.fromJson(Map<
String, dynamic> json) -
factory
- AnalyticsIkonProxyServerStats.fromReader(TeleportObjectReader reader)
-
factory
- AnalyticsIkonProxyServerStats.fromTeleport(Uint8List data)
-
factory
Properties
- channelCount ↔ int
-
getter/setter pair
- cpuUsagePercentage ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- managedMemoryUsedMb ↔ double
-
getter/setter pair
- memoryInfo ↔ String
-
getter/setter pair
- processMemoryUsedMb ↔ double
-
getter/setter pair
- receivedMessagesBandwidthKb ↔ double
-
getter/setter pair
- receivedMessagesCount ↔ int
-
getter/setter pair
- receivedMessagesPerSecond ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentMessagesBandwidthKb ↔ double
-
getter/setter pair
- sentMessagesCount ↔ int
-
getter/setter pair
- sentMessagesPerSecond ↔ double
-
getter/setter pair
- time ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdChannelCount → const int
- fieldIdCpuUsagePercentage → const int
- fieldIdManagedMemoryUsedMb → const int
- fieldIdMemoryInfo → const int
- fieldIdProcessMemoryUsedMb → const int
- fieldIdReceivedMessagesBandwidthKb → const int
- fieldIdReceivedMessagesCount → const int
- fieldIdReceivedMessagesPerSecond → const int
- fieldIdSentMessagesBandwidthKb → const int
- fieldIdSentMessagesCount → const int
- fieldIdSentMessagesPerSecond → const int
- fieldIdTime → const int
- teleportOpcode → const int
- teleportVersion → const int