AnalyticsIkonTurnServerStats class
Constructors
- AnalyticsIkonTurnServerStats({String time = '', int activeAllocationCount = 0, int activeConnectionCount = 0, int channelBindingCount = 0, int totalAllocationsCreated = 0, double cpuUsagePercentage = 0.0, double processMemoryUsedMb = 0.0, double managedMemoryUsedMb = 0.0, String memoryInfo = ''})
-
AnalyticsIkonTurnServerStats.fromJson(Map<
String, dynamic> json) -
factory
- AnalyticsIkonTurnServerStats.fromReader(TeleportObjectReader reader)
-
factory
- AnalyticsIkonTurnServerStats.fromTeleport(Uint8List data)
-
factory
Properties
- activeAllocationCount ↔ int
-
getter/setter pair
- activeConnectionCount ↔ int
-
getter/setter pair
- channelBindingCount ↔ int
-
getter/setter pair
- cpuUsagePercentage ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- managedMemoryUsedMb ↔ double
-
getter/setter pair
- memoryInfo ↔ String
-
getter/setter pair
- processMemoryUsedMb ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time ↔ String
-
getter/setter pair
- totalAllocationsCreated ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdActiveAllocationCount → const int
- fieldIdActiveConnectionCount → const int
- fieldIdChannelBindingCount → const int
- fieldIdCpuUsagePercentage → const int
- fieldIdManagedMemoryUsedMb → const int
- fieldIdMemoryInfo → const int
- fieldIdProcessMemoryUsedMb → const int
- fieldIdTime → const int
- fieldIdTotalAllocationsCreated → const int
- teleportOpcode → const int
- teleportVersion → const int