AnalyticsLogs class

Constructors

AnalyticsLogs({List<AnalyticsLogsItem> logs = const []})
AnalyticsLogs.fromJson(Map<String, dynamic> json)
factory
AnalyticsLogs.fromReader(TeleportObjectReader reader)
factory
AnalyticsLogs.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
logs List<AnalyticsLogsItem>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdLogs → const int
teleportOpcode → const int
teleportVersion → const int