AnalyticsTrafficUsageItem class

Constructors

AnalyticsTrafficUsageItem({String tenant = '', int bytesToClient = 0, int bytesFromClient = 0})
AnalyticsTrafficUsageItem.fromJson(Map<String, dynamic> json)
factory
AnalyticsTrafficUsageItem.fromReader(TeleportObjectReader reader)
factory
AnalyticsTrafficUsageItem.fromTeleport(Uint8List data)
factory

Properties

bytesFromClient int
getter/setter pair
bytesToClient int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenant String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
toTeleport() Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdBytesFromClient → const int
fieldIdBytesToClient → const int
fieldIdTenant → const int
teleportVersion → const int