AnalyticsUsage class

Constructors

AnalyticsUsage({String usageName = '', double usage = 0.0})
AnalyticsUsage.fromJson(Map<String, dynamic> json)
factory
AnalyticsUsage.fromReader(TeleportObjectReader reader)
factory
AnalyticsUsage.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage double
getter/setter pair
usageName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdUsage → const int
fieldIdUsageName → const int
teleportOpcode → const int
teleportVersion → const int