AnalyticsUsages class
Constructors
-
AnalyticsUsages({List<
AnalyticsUsagesItem> usages = const []}) -
AnalyticsUsages.fromJson(Map<
String, dynamic> json) -
factory
- AnalyticsUsages.fromReader(TeleportObjectReader reader)
-
factory
- AnalyticsUsages.fromTeleport(Uint8List data)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
usages
↔ List<
AnalyticsUsagesItem> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdUsages → const int
- teleportOpcode → const int
- teleportVersion → const int