AudioFrame class

Constructors

AudioFrame({List<int> samples = const [], int epoch = 0, int sequence = 0, int frameSizeInInterleavedSamples = 0, int timeStampInInterleavedSamples = 0, bool isFirst = false, bool isLast = false, double averageVolume = 0.0, double audioEventEstimatedDuration = 0.0})
AudioFrame.fromJson(Map<String, dynamic> json)
factory
AudioFrame.fromReader(TeleportObjectReader reader)
factory
AudioFrame.fromTeleport(Uint8List data)
factory

Properties

audioEventEstimatedDuration ↔ double
getter/setter pair
averageVolume ↔ double
getter/setter pair
epoch ↔ int
getter/setter pair
frameSizeInInterleavedSamples ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFirst ↔ bool
getter/setter pair
isLast ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ List<int>
getter/setter pair
sequence ↔ int
getter/setter pair
timeStampInInterleavedSamples ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toProtocolMessage(int senderId, {ProtocolMessageOverrides? overrides}) → ProtocolMessage
toString() → String
A string representation of this object.
inherited
toTeleport() → Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited