AudioPlaybackReport class

Constructors

AudioPlaybackReport({int epoch = 0, double playedSeconds = 0.0, double bufferedMs = 0.0, AudioPlaybackState state = AudioPlaybackState.unknown})
AudioPlaybackReport.fromJson(Map<String, dynamic> json)
factory
AudioPlaybackReport.fromReader(TeleportObjectReader reader)
factory
AudioPlaybackReport.fromTeleport(Uint8List data)
factory

Properties

bufferedMs double
getter/setter pair
epoch int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
playedSeconds double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AudioPlaybackState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toProtocolMessage(int senderId, {ProtocolMessageOverrides? overrides}) ProtocolMessage
toString() String
A string representation of this object.
inherited
toTeleport() Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdBufferedMs → const int
fieldIdEpoch → const int
fieldIdPlayedSeconds → const int
fieldIdState → const int
teleportOpcode → const int
teleportVersion → const int