AudioShapeFrame class

Constructors

AudioShapeFrame({int epoch = 0, int sequence = 0, int frameSizeInInterleavedSamples = 0, int timeStampInInterleavedSamples = 0, List<AudioShapeSetValues> shapeSetValues = const []})
AudioShapeFrame.fromJson(Map<String, dynamic> json)
factory
AudioShapeFrame.fromReader(TeleportObjectReader reader)
factory
AudioShapeFrame.fromTeleport(Uint8List data)
factory

Properties

epoch int
getter/setter pair
frameSizeInInterleavedSamples int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
getter/setter pair
shapeSetValues List<AudioShapeSetValues>
getter/setter pair
timeStampInInterleavedSamples int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited