AudioShapeSetValues class

Constructors

AudioShapeSetValues({int setId = 0, List<double> values = const [], String? playbackId, String? slot})
AudioShapeSetValues.fromJson(Map<String, dynamic> json)
factory
AudioShapeSetValues.fromReader(TeleportObjectReader reader)
factory
AudioShapeSetValues.fromTeleport(Uint8List data)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
playbackId ↔ String?
The playback these values were analysed from, so a client can follow one speaker
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setId ↔ int
getter/setter pair
slot ↔ String?
The slot of that playback
getter/setter pair
values ↔ List<double>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toTeleport() → Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fieldIdPlaybackId → const int
fieldIdSetId → const int
fieldIdSlot → const int
fieldIdValues → const int
teleportVersion → const int