AudioStreamBegin class

Constructors

AudioStreamBegin({String streamId = '', String description = '', String sourceType = '', AudioCodec codec = AudioCodec.unknown, String codecDetails = '', int sampleRate = 0, int channels = 0, List<AudioShapeSet>? shapeSets, String? correlationId})
AudioStreamBegin.fromJson(Map<String, dynamic> json)
factory
AudioStreamBegin.fromReader(TeleportObjectReader reader)
factory
AudioStreamBegin.fromTeleport(Uint8List data)
factory

Properties

channels int
getter/setter pair
codec AudioCodec
getter/setter pair
codecDetails String
getter/setter pair
correlationId String?
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair
shapeSets List<AudioShapeSet>?
getter/setter pair
sourceType String
getter/setter pair
streamId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdChannels → const int
fieldIdCodec → const int
fieldIdCodecDetails → const int
fieldIdCorrelationId → const int
fieldIdDescription → const int
fieldIdSampleRate → const int
fieldIdShapeSets → const int
fieldIdSourceType → const int
fieldIdStreamId → const int
teleportOpcode → const int
teleportVersion → const int