appSessionId property

String appSessionId
getter/setter pair

The app session this server was provisioned for — the session's business identity, stable across the servers that run it.

Implementation

String appSessionId;