MessageFlag enum
Values
- none → const MessageFlag
-
const MessageFlag(0) - sendBackToSender → const MessageFlag
-
const MessageFlag(1) - delayable → const MessageFlag
-
const MessageFlag(2) - sendToUser → const MessageFlag
-
const MessageFlag(4) - compressed → const MessageFlag
-
const MessageFlag(8) - unreliable → const MessageFlag
-
const MessageFlag(16)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → MessageFlag
Constants
-
values
→ const List<
MessageFlag> - A constant List of the values in this enum, in order of their declaration.