UIHeaderLevel enum
Values
- default_ → const UIHeaderLevel
-
const UIHeaderLevel(0) - large → const UIHeaderLevel
-
const UIHeaderLevel(1) - medium → const UIHeaderLevel
-
const UIHeaderLevel(2) - normal → const UIHeaderLevel
-
const UIHeaderLevel(3) - small → const UIHeaderLevel
-
const UIHeaderLevel(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → UIHeaderLevel
Constants
-
values
→ const List<
UIHeaderLevel> - A constant List of the values in this enum, in order of their declaration.