VideoCodec enum
Values
- unknown → const VideoCodec
-
const VideoCodec(0) - H264 → const VideoCodec
-
const VideoCodec(1) - vp8 → const VideoCodec
-
const VideoCodec(2) - vp9 → const VideoCodec
-
const VideoCodec(3) - av1 → const VideoCodec
-
const VideoCodec(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → VideoCodec
Constants
-
values
→ const List<
VideoCodec> - A constant List of the values in this enum, in order of their declaration.