ActionFunctionApprovalResponse class

Constructors

ActionFunctionApprovalResponse({String approvalId = '', String approvalToken = '', bool approved = false, String rejectionReason = ''})
ActionFunctionApprovalResponse.fromJson(Map<String, dynamic> json)
factory
ActionFunctionApprovalResponse.fromReader(TeleportObjectReader reader)
factory
ActionFunctionApprovalResponse.fromTeleport(Uint8List data)
factory

Properties

approvalId String
getter/setter pair
approvalToken String
getter/setter pair
approved bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rejectionReason String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdApprovalId → const int
fieldIdApprovalToken → const int
fieldIdApproved → const int
fieldIdRejectionReason → const int
teleportOpcode → const int
teleportVersion → const int