ActionFunctionAwaitingApproval class

Constructors

ActionFunctionAwaitingApproval({String callId = '', String approvalId = '', String functionName = '', String reason = '', int timeoutSeconds = 0})
ActionFunctionAwaitingApproval.fromJson(Map<String, dynamic> json)
factory
ActionFunctionAwaitingApproval.fromReader(TeleportObjectReader reader)
factory
ActionFunctionAwaitingApproval.fromTeleport(Uint8List data)
factory

Properties

approvalId String
getter/setter pair
callId String
getter/setter pair
functionName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reason String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutSeconds int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdApprovalId → const int
fieldIdCallId → const int
fieldIdFunctionName → const int
fieldIdReason → const int
fieldIdTimeoutSeconds → const int
teleportOpcode → const int
teleportVersion → const int