ActionFunctionEnumerationEnd class
Constructors
- ActionFunctionEnumerationEnd({String callId = '', String instanceId = '', String enumerationId = ''})
-
ActionFunctionEnumerationEnd.fromJson(Map<
String, dynamic> json) -
factory
- ActionFunctionEnumerationEnd.fromReader(TeleportObjectReader reader)
-
factory
- ActionFunctionEnumerationEnd.fromTeleport(Uint8List data)
-
factory
Properties
- callId ↔ String
-
getter/setter pair
- enumerationId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdCallId → const int
- fieldIdEnumerationId → const int
- fieldIdInstanceId → const int
- teleportOpcode → const int
- teleportVersion → const int