ActionFunctionEnumerationItem class

Constructors

ActionFunctionEnumerationItem({String callId = '', String instanceId = '', String enumerationId = '', int itemIndex = 0, String itemTypeName = '', String itemJson = '', List<int> itemData = const [], List<int> itemTeleport = const []})
ActionFunctionEnumerationItem.fromJson(Map<String, dynamic> json)
factory
ActionFunctionEnumerationItem.fromReader(TeleportObjectReader reader)
factory
ActionFunctionEnumerationItem.fromTeleport(Uint8List data)
factory

Properties

callId String
getter/setter pair
enumerationId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId String
getter/setter pair
itemData List<int>
getter/setter pair
itemIndex int
getter/setter pair
itemJson String
getter/setter pair
itemTeleport List<int>
getter/setter pair
itemTypeName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCallId → const int
fieldIdEnumerationId → const int
fieldIdInstanceId → const int
fieldIdItemData → const int
fieldIdItemIndex → const int
fieldIdItemJson → const int
fieldIdItemTeleport → const int
fieldIdItemTypeName → const int
teleportOpcode → const int
teleportVersion → const int