ActionFunctionRegisterBatch class
Constructors
-
ActionFunctionRegisterBatch({List<
ActionFunctionRegister> functions = const []}) -
ActionFunctionRegisterBatch.fromJson(Map<
String, dynamic> json) -
factory
- ActionFunctionRegisterBatch.fromReader(TeleportObjectReader reader)
-
factory
- ActionFunctionRegisterBatch.fromTeleport(Uint8List data)
-
factory
Properties
-
functions
↔ List<
ActionFunctionRegister> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdFunctions → const int
- teleportOpcode → const int
- teleportVersion → const int