ActionFunctionResult class

Constructors

ActionFunctionResult({String callId = '', String instanceId = '', String resultTypeName = '', String resultJson = '', List<int> resultData = const [], List<int> resultTeleport = const []})
ActionFunctionResult.fromJson(Map<String, dynamic> json)
factory
ActionFunctionResult.fromReader(TeleportObjectReader reader)
factory
ActionFunctionResult.fromTeleport(Uint8List data)
factory

Properties

callId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId String
getter/setter pair
resultData List<int>
getter/setter pair
resultJson String
getter/setter pair
resultTeleport List<int>
getter/setter pair
resultTypeName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCallId → const int
fieldIdInstanceId → const int
fieldIdResultData → const int
fieldIdResultJson → const int
fieldIdResultTeleport → const int
fieldIdResultTypeName → const int
teleportOpcode → const int
teleportVersion → const int