FunctionParameter class

Constructors

FunctionParameter({int parameterIndex = 0, String typeName = '', String valueJson = '', List<int> valueData = const [], bool isEnumerable = false, String enumerableItemTypeName = '', String enumerationId = '', List<int> valueTeleport = const []})
FunctionParameter.fromJson(Map<String, dynamic> json)
factory
FunctionParameter.fromReader(TeleportObjectReader reader)
factory
FunctionParameter.fromTeleport(Uint8List data)
factory

Properties

enumerableItemTypeName String
getter/setter pair
enumerationId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isEnumerable bool
getter/setter pair
parameterIndex int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String
getter/setter pair
valueData List<int>
getter/setter pair
valueJson String
getter/setter pair
valueTeleport List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited