FunctionRegisterParameter class

Constructors

FunctionRegisterParameter({int parameterIndex = 0, String parameterName = '', String typeName = '', bool hasDefaultValue = false, String defaultValueJson = '', List<int> defaultValueData = const [], bool isEnumerable = false, String enumerableItemTypeName = '', String description = ''})
FunctionRegisterParameter.fromJson(Map<String, dynamic> json)
factory
FunctionRegisterParameter.fromReader(TeleportObjectReader reader)
factory
FunctionRegisterParameter.fromTeleport(Uint8List data)
factory

Properties

defaultValueData List<int>
getter/setter pair
defaultValueJson String
getter/setter pair
description String
getter/setter pair
enumerableItemTypeName String
getter/setter pair
hasDefaultValue bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isEnumerable bool
getter/setter pair
parameterIndex int
getter/setter pair
parameterName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited