firstUserId property
User ID of the first human user who joined this session, dynamically reassigned when that user leaves
Implementation
String firstUserId;
User ID of the first human user who joined this session, dynamically reassigned when that user leaves
String firstUserId;