functions property
Registry of callable functions organized by client session ID
Implementation
Map<int, List<ActionFunctionRegister>> functions;
Registry of callable functions organized by client session ID
Map<int, List<ActionFunctionRegister>> functions;