primaryUserId property
Static user ID of the session owner from server configuration, used for user-specific asset storage paths
Implementation
String primaryUserId;
Static user ID of the session owner from server configuration, used for user-specific asset storage paths
String primaryUserId;