VideoStreamState class

Constructors

VideoStreamState({String streamId = '', int clientSessionId = 0, int trackId = 0, VideoStreamBegin? info})
VideoStreamState.fromJson(Map<String, dynamic> json)
factory
VideoStreamState.fromReader(TeleportObjectReader reader)
factory
VideoStreamState.fromTeleport(Uint8List data)
factory

Properties

clientSessionId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info VideoStreamBegin?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String
getter/setter pair
trackId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdClientSessionId → const int
fieldIdInfo → const int
fieldIdStreamId → const int
fieldIdTrackId → const int
teleportVersion → const int