ServerInit2 class
Constructors
-
ServerInit2({String sessionId = '', Map<
String, String> sessionIdentity = const {}}) -
ServerInit2.fromJson(Map<
String, dynamic> json) -
factory
- ServerInit2.fromReader(TeleportObjectReader reader)
-
factory
- ServerInit2.fromTeleport(Uint8List data)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId ↔ String
-
getter/setter pair
-
sessionIdentity
↔ Map<
String, String> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdSessionId → const int
- fieldIdSessionIdentity → const int
- teleportOpcode → const int
- teleportVersion → const int