ServerPluginInit class

Constructors

ServerPluginInit({bool enabled = false, String bundleDirectoryPath = '', List<int> bundleDirectoryZipContent = const [], String dllName = '', String typeName = '', String configFilePath = '', String configJsonContent = '', List<ServerPluginInitExtraConfig> extraConfigs = const []})
ServerPluginInit.fromJson(Map<String, dynamic> json)
factory
ServerPluginInit.fromReader(TeleportObjectReader reader)
factory
ServerPluginInit.fromTeleport(Uint8List data)
factory

Properties

bundleDirectoryPath String
getter/setter pair
bundleDirectoryZipContent List<int>
getter/setter pair
configFilePath String
getter/setter pair
configJsonContent String
getter/setter pair
dllName String
getter/setter pair
enabled bool
getter/setter pair
extraConfigs List<ServerPluginInitExtraConfig>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited