ServerStart class

Constructors

ServerStart({String hostServerSessionId = '', String configJsonContent = ''})
ServerStart.fromJson(Map<String, dynamic> json)
factory
ServerStart.fromReader(TeleportObjectReader reader)
factory
ServerStart.fromTeleport(Uint8List data)
factory

Properties

configJsonContent String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostServerSessionId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited