ServerStop class

Constructors

ServerStop({String hostServerSessionId = '', String targetServerSessionId = ''})
ServerStop.fromJson(Map<String, dynamic> json)
factory
ServerStop.fromReader(TeleportObjectReader reader)
factory
ServerStop.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hostServerSessionId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetServerSessionId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited