BackgroundWorkActive class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isActive ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toProtocolMessage(int senderId, {ProtocolMessageOverrides? overrides}) → ProtocolMessage
toString() → String
A string representation of this object.
inherited
toTeleport() → Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fieldIdIsActive → const int
teleportOpcode → const int
teleportVersion → const int