OnUserDataErased class

Constructors

OnUserDataErased({String requestId = '', List<String> userIds = const []})
OnUserDataErased.fromJson(Map<String, dynamic> json)
factory
OnUserDataErased.fromReader(TeleportObjectReader reader)
factory
OnUserDataErased.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
requestId String
The ActionUserDataErasure.RequestId this acknowledges.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toProtocolMessage(int senderId, {ProtocolMessageOverrides? overrides}) ProtocolMessage
toString() String
A string representation of this object.
inherited
toTeleport() Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdRequestId → const int
fieldIdUserIds → const int
teleportOpcode → const int
teleportVersion → const int