UpdateClientContext class

Constructors

UpdateClientContext({int viewportWidth = 0, int viewportHeight = 0, String theme = '', String timezone = ''})
UpdateClientContext.fromJson(Map<String, dynamic> json)
factory
UpdateClientContext.fromReader(TeleportObjectReader reader)
factory
UpdateClientContext.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme String
getter/setter pair
timezone String
getter/setter pair
viewportHeight int
getter/setter pair
viewportWidth int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdTheme → const int
fieldIdTimezone → const int
fieldIdViewportHeight → const int
fieldIdViewportWidth → const int
teleportOpcode → const int
teleportVersion → const int