protocol/generated/protocol library

Classes

Action
ActionActive
ActionAudioStop
ActionCall
ActionCall2
ActionCallAck
ActionCallResult
ActionCallText
ActionCancelGeneration
ActionClassificationDetail
ActionClassificationResult
ActionClearState
ActionCustomUserMessage
ActionDownload
ActionFileUploadAck2
ActionFileUploadComplete2
ActionFileUploadData2
ActionFileUploadEnd2
ActionFileUploadPreStart2
ActionFileUploadPreStartResponse2
ActionFileUploadResume2
ActionFileUploadResumeResponse2
ActionFileUploadStart2
ActionFileUploadStartResponse2
ActionFunctionAck
ActionFunctionApprovalRequired
ActionFunctionApprovalResponse
ActionFunctionAwaitingApproval
ActionFunctionCall
ActionFunctionCancel
ActionFunctionDispose
ActionFunctionEnumerationEnd
ActionFunctionEnumerationItem
ActionFunctionEnumerationItemBatch
ActionFunctionError
ActionFunctionRegister
ActionFunctionRegisterBatch
ActionFunctionResult
ActionGenerateAnswer
ActionOpenExternalUrl
ActionPan
ActionPlaySound
ActionRegenerateAnswer
ActionResult
ActionSetState
ActionSpeechRecognized
ActionStartRecording
ActionStopRecording
ActionStopSound
ActionTap
ActionTextOutput
ActionTextOutputDelta
ActionTextOutputDeltaFull
ActionTriggerCron
ActionUrlChanged
ActionUserDataErasure
ActionZoom
AnalyticsEvents
AnalyticsEventsItem
AnalyticsIkonHostServerStats
AnalyticsIkonProxyServerStats
AnalyticsIkonRelayServerStats
AnalyticsIkonTurnServerStats
AnalyticsLogs
AnalyticsLogsItem
AnalyticsProcessingUpdate
AnalyticsReactiveProcessingUpdate
AnalyticsSpecialLog
AnalyticsTrafficUsage
AnalyticsTrafficUsageItem
AnalyticsUsage
AnalyticsUsages
AnalyticsUsagesItem
AppConfig
AudioFrame
AudioFrameVolume
AudioPlaybackReport
AudioShapeFrame
AudioShapeSet
AudioShapeSetValues
AudioStreamBegin
AudioStreamEnd
AudioStreamState
AuthResponse
AuthResponseRetiredFields
Typed bag of this type's retired keys; a null member means the source carried no value.
AuthTicket
BackgroundWorkActive
ClientDisconnecting
ClientEnvironment
ClientInitialization
ClientLifecycleBatch
ClientLifecycleEvent
ClientReady
ConnectToken
Context
Coordinate2D
DynamicConfig
Entrypoint
EventsOnProfileUpdate
EventsSpeechPlaybackCompleted
FunctionParameter
FunctionRegisterParameter
GlobalState
Shared state synchronized across all clients and the server, providing access to connected clients, registered functions, active media streams, and session metadata
GlobalStateRetiredFields
Typed bag of this type's retired keys; a null member means the source carried no value.
IkonServerEndpointHostInfo
InvalidateVideoFrame
KeepaliveRequest
KeepaliveResponse
OnAppReady
OnClientJoined
OnClientLeft
OnClientReady
OnFrontendReloaded
OnPluginReloaded
OnServerStarted
OnServerStatusPing
OnServerStopped
OnServerStopping
OnUserDataErased
OnUserJoined
OnUserLeft
ProxyRpcAuthTicket
RelayAddTunnel
RelayAgentAuth
RelayAgentAuthResult
RelayHeartbeat
RelayRemoveTunnel
RelayTcpConnectionClosed
RelayTcpConnectionOpened
RelayTcpData
RelayTunnelAdded
RelayUdpData
RequestIdrVideoFrame
ResetIdle
RouteToken
ScopeEntry
ServerExtensionInit
ServerInit
ServerInitDatabaseConnectionInfo
ServerInitRetiredFields
Typed bag of this type's retired keys; a null member means the source carried no value.
ServerPluginInit
ServerPluginInitExtraConfig
UIElementLabels
UIPayload
UIResyncRequest
UIStreamBegin
UIStreamCategories
UIStreamEnd
UIStreamState
UIStyles
UIStylesBatch
UIStylesBatchItem
UIStylesDelete
UIStylesKeys
UIUpdate
UIUpdateAck
UpdateClientContext
UserCredentialEntry
VideoFrame
VideoStreamBegin
VideoStreamEnd
VideoStreamState
WebRTCAnswer
WebRTCAudioSegment
WebRTCClose
WebRTCIceCandidate
WebRTCIceServersRequest
WebRTCIceServersResponse
WebRTCOffer
WebRTCReady
WebRTCTrackMap
WebRTCVideoCapture

Constants

protocolVersion → const int
The wire protocol version this SDK generation targets.