RelayAddTunnel class

Constructors

RelayAddTunnel({int requestId = 0, String protocol = '', int localPort = 0, bool terminateTls = false, String stablePortName = ''})
RelayAddTunnel.fromJson(Map<String, dynamic> json)
factory
RelayAddTunnel.fromReader(TeleportObjectReader reader)
factory
RelayAddTunnel.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
localPort int
getter/setter pair
protocol String
getter/setter pair
requestId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stablePortName String
getter/setter pair
terminateTls bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdLocalPort → const int
fieldIdProtocol → const int
fieldIdRequestId → const int
fieldIdStablePortName → const int
fieldIdTerminateTls → const int
teleportOpcode → const int
teleportVersion → const int