RelayAgentAuth class

Constructors

RelayAgentAuth({String authToken = '', String stableId = '', String agentInstanceId = ''})
RelayAgentAuth.fromJson(Map<String, dynamic> json)
factory
RelayAgentAuth.fromReader(TeleportObjectReader reader)
factory
RelayAgentAuth.fromTeleport(Uint8List data)
factory

Properties

agentInstanceId String
getter/setter pair
authToken String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stableId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdAgentInstanceId → const int
fieldIdAuthToken → const int
fieldIdStableId → const int
teleportOpcode → const int
teleportVersion → const int