RelayTcpConnectionOpened class
Constructors
- RelayTcpConnectionOpened({int tunnelId = 0, int connectionId = 0})
-
RelayTcpConnectionOpened.fromJson(Map<
String, dynamic> json) -
factory
- RelayTcpConnectionOpened.fromReader(TeleportObjectReader reader)
-
factory
- RelayTcpConnectionOpened.fromTeleport(Uint8List data)
-
factory
Properties
- connectionId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tunnelId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdConnectionId → const int
- fieldIdTunnelId → const int
- teleportOpcode → const int
- teleportVersion → const int