RelayTcpData class

Constructors

RelayTcpData({int tunnelId = 0, int connectionId = 0, List<int> data = const []})
RelayTcpData.fromJson(Map<String, dynamic> json)
factory
RelayTcpData.fromReader(TeleportObjectReader reader)
factory
RelayTcpData.fromTeleport(Uint8List data)
factory

Properties

connectionId int
getter/setter pair
data List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tunnelId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdConnectionId → const int
fieldIdData → const int
fieldIdTunnelId → const int
teleportOpcode → const int
teleportVersion → const int