SceneArray class

Constructors

SceneArray({int serializerType = 0, String type_ = '', String subId = '', int elementOffset = 0, int elementCount = 0, int byteOffset = 0, int typeSize = 0, int strideSize = 0, List<int> byteArray = const []})
SceneArray.fromJson(Map<String, dynamic> json)
factory
SceneArray.fromReader(TeleportObjectReader reader)
factory
SceneArray.fromTeleport(Uint8List data)
factory

Properties

byteArray List<int>
getter/setter pair
byteOffset int
getter/setter pair
elementCount int
getter/setter pair
elementOffset int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializerType int
getter/setter pair
strideSize int
getter/setter pair
subId String
getter/setter pair
type_ String
getter/setter pair
typeSize int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdByteArray → const int
fieldIdByteOffset → const int
fieldIdElementCount → const int
fieldIdElementOffset → const int
fieldIdSerializerType → const int
fieldIdStrideSize → const int
fieldIdSubId → const int
fieldIdType → const int
fieldIdTypeSize → const int
teleportOpcode → const int
teleportVersion → const int