TrackingStreamBegin class

Constructors

TrackingStreamBegin({String category = '', TrackingType type_ = TrackingType.face, List<String> faceBlendshapes = const []})
TrackingStreamBegin.fromJson(Map<String, dynamic> json)
factory
TrackingStreamBegin.fromReader(TeleportObjectReader reader)
factory
TrackingStreamBegin.fromTeleport(Uint8List data)
factory

Properties

category String
getter/setter pair
faceBlendshapes List<String>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ TrackingType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCategory → const int
fieldIdFaceBlendshapes → const int
fieldIdType → const int
teleportOpcode → const int
teleportVersion → const int