UIAutocomplete class

Constructors

UIAutocomplete({int elementId = 0, List<String> labels = const [], String styleId = '', String name = '', List<UIAutocompleteOption> options = const [], String updateActionId = '', int minCount = 0, int maxCount = 0, UIColor color = UIColor.default_, UIInputVariant variant = UIInputVariant.outlined, List<String> initialValue = const [], String placeholder = ''})
UIAutocomplete.fromJson(Map<String, dynamic> json)
factory
UIAutocomplete.fromReader(TeleportObjectReader reader)
factory
UIAutocomplete.fromTeleport(Uint8List data)
factory

Properties

color UIColor
getter/setter pair
elementId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialValue List<String>
getter/setter pair
labels List<String>
getter/setter pair
maxCount int
getter/setter pair
minCount int
getter/setter pair
name String
getter/setter pair
options List<UIAutocompleteOption>
getter/setter pair
placeholder String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String
getter/setter pair
updateActionId String
getter/setter pair
variant UIInputVariant
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdColor → const int
fieldIdElementId → const int
fieldIdInitialValue → const int
fieldIdLabels → const int
fieldIdMaxCount → const int
fieldIdMinCount → const int
fieldIdName → const int
fieldIdOptions → const int
fieldIdPlaceholder → const int
fieldIdStyleId → const int
fieldIdUpdateActionId → const int
fieldIdVariant → const int
teleportOpcode → const int
teleportVersion → const int