UIContainerBegin class

Constructors

UIContainerBegin({String containerId = '', String userId = '', String createdAt = '', String updatedAt = '', String alternativeText = '', bool isTransient = false, bool isHistory = false, bool isUpdate = false, int groupId = 0, int sortingId = 0, bool isStable = true, UIVisibilityType visibility = UIVisibilityType.always, int preciseCreatedAt = 0, String optimisticActionId = ''})
UIContainerBegin.fromJson(Map<String, dynamic> json)
factory
UIContainerBegin.fromReader(TeleportObjectReader reader)
factory
UIContainerBegin.fromTeleport(Uint8List data)
factory

Properties

alternativeText String
getter/setter pair
containerId String
getter/setter pair
createdAt String
getter/setter pair
groupId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isHistory bool
getter/setter pair
isStable bool
getter/setter pair
isTransient bool
getter/setter pair
isUpdate bool
getter/setter pair
optimisticActionId String
getter/setter pair
preciseCreatedAt int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortingId int
getter/setter pair
updatedAt String
getter/setter pair
userId String
getter/setter pair
visibility UIVisibilityType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited