UIFile class

Constructors

UIFile({int elementId = 0, List<String> labels = const [], String styleId = '', String name = '', String secondaryText = '', String type_ = '', String mime = '', List<String> allowedMimeTypes = const [], int maxSize = 0, UIFileInfo? fileInfo, String openActionId = '', String uploadActionId = '', String removeActionId = ''})
UIFile.fromJson(Map<String, dynamic> json)
factory
UIFile.fromReader(TeleportObjectReader reader)
factory
UIFile.fromTeleport(Uint8List data)
factory

Properties

allowedMimeTypes List<String>
getter/setter pair
elementId int
getter/setter pair
fileInfo UIFileInfo?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels List<String>
getter/setter pair
maxSize int
getter/setter pair
mime String
getter/setter pair
name String
getter/setter pair
openActionId String
getter/setter pair
removeActionId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryText String
getter/setter pair
styleId String
getter/setter pair
type_ String
getter/setter pair
uploadActionId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdAllowedMimeTypes → const int
fieldIdElementId → const int
fieldIdFileInfo → const int
fieldIdLabels → const int
fieldIdMaxSize → const int
fieldIdMime → const int
fieldIdName → const int
fieldIdOpenActionId → const int
fieldIdRemoveActionId → const int
fieldIdSecondaryText → const int
fieldIdStyleId → const int
fieldIdType → const int
fieldIdUploadActionId → const int
teleportOpcode → const int
teleportVersion → const int