UIFileUploadSectionBegin class
Constructors
-
UIFileUploadSectionBegin({int elementId = 0, List<
String> labels = const [], String styleId = '', int gap = 0, String uploadActionId = '', List<String> allowedMimeTypes = const [], int maxSize = 0}) -
UIFileUploadSectionBegin.fromJson(Map<
String, dynamic> json) -
factory
- UIFileUploadSectionBegin.fromReader(TeleportObjectReader reader)
-
factory
- UIFileUploadSectionBegin.fromTeleport(Uint8List data)
-
factory
Properties
-
allowedMimeTypes
↔ List<
String> -
getter/setter pair
- elementId ↔ int
-
getter/setter pair
- gap ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ List<
String> -
getter/setter pair
- maxSize ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleId ↔ String
-
getter/setter pair
- uploadActionId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdAllowedMimeTypes → const int
- fieldIdElementId → const int
- fieldIdGap → const int
- fieldIdLabels → const int
- fieldIdMaxSize → const int
- fieldIdStyleId → const int
- fieldIdUploadActionId → const int
- teleportOpcode → const int
- teleportVersion → const int