UIIcon class
Constructors
-
UIIcon({int elementId = 0, List<
String> labels = const [], String styleId = '', UIIconType icon = UIIconType.none, UIColor color = UIColor.default_}) -
UIIcon.fromJson(Map<
String, dynamic> json) -
factory
- UIIcon.fromReader(TeleportObjectReader reader)
-
factory
- UIIcon.fromTeleport(Uint8List data)
-
factory
Properties
- color ↔ UIColor
-
getter/setter pair
- elementId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ UIIconType
-
getter/setter pair
-
labels
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdColor → const int
- fieldIdElementId → const int
- fieldIdIcon → const int
- fieldIdLabels → const int
- fieldIdStyleId → const int
- teleportOpcode → const int
- teleportVersion → const int