UIIconButton class
Constructors
-
UIIconButton({int elementId = 0, List<
String> labels = const [], String styleId = '', UIIconType icon = UIIconType.none, UIColor color = UIColor.default_, String clickActionId = '', String pressStartActionId = '', String pressEndActionId = '', String pressChangeActionId = '', String pressUpActionId = '', String dragStartActionId = '', String dragEnterActionId = '', String dragLeaveActionId = '', String dragOverActionId = '', String dropActionId = '', String dragEndActionId = ''}) -
UIIconButton.fromJson(Map<
String, dynamic> json) -
factory
- UIIconButton.fromReader(TeleportObjectReader reader)
-
factory
- UIIconButton.fromTeleport(Uint8List data)
-
factory
Properties
- clickActionId ↔ String
-
getter/setter pair
- color ↔ UIColor
-
getter/setter pair
- dragEndActionId ↔ String
-
getter/setter pair
- dragEnterActionId ↔ String
-
getter/setter pair
- dragLeaveActionId ↔ String
-
getter/setter pair
- dragOverActionId ↔ String
-
getter/setter pair
- dragStartActionId ↔ String
-
getter/setter pair
- dropActionId ↔ String
-
getter/setter pair
- elementId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ UIIconType
-
getter/setter pair
-
labels
↔ List<
String> -
getter/setter pair
- pressChangeActionId ↔ String
-
getter/setter pair
- pressEndActionId ↔ String
-
getter/setter pair
- pressStartActionId ↔ String
-
getter/setter pair
- pressUpActionId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdClickActionId → const int
- fieldIdColor → const int
- fieldIdDragEndActionId → const int
- fieldIdDragEnterActionId → const int
- fieldIdDragLeaveActionId → const int
- fieldIdDragOverActionId → const int
- fieldIdDragStartActionId → const int
- fieldIdDropActionId → const int
- fieldIdElementId → const int
- fieldIdIcon → const int
- fieldIdLabels → const int
- fieldIdPressChangeActionId → const int
- fieldIdPressEndActionId → const int
- fieldIdPressStartActionId → const int
- fieldIdPressUpActionId → const int
- fieldIdStyleId → const int
- teleportOpcode → const int
- teleportVersion → const int