UIInit class

Constructors

UIInit({List<UIInitModule> modules = const []})
UIInit.fromJson(Map<String, dynamic> json)
factory
UIInit.fromReader(TeleportObjectReader reader)
factory
UIInit.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
modules List<UIInitModule>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdModules → const int
teleportOpcode → const int
teleportVersion → const int