UIInputText class

Constructors

UIInputText({int elementId = 0, List<String> labels = const [], String styleId = '', String name = '', String updateActionId = '', UIColor color = UIColor.default_, UIInputVariant variant = UIInputVariant.outlined, int rows = 1, String initialValue = '', String submitActionId = ''})
UIInputText.fromJson(Map<String, dynamic> json)
factory
UIInputText.fromReader(TeleportObjectReader reader)
factory
UIInputText.fromTeleport(Uint8List data)
factory

Properties

color UIColor
getter/setter pair
elementId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialValue String
getter/setter pair
labels List<String>
getter/setter pair
name String
getter/setter pair
rows int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String
getter/setter pair
submitActionId String
getter/setter pair
updateActionId String
getter/setter pair
variant UIInputVariant
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdColor → const int
fieldIdElementId → const int
fieldIdInitialValue → const int
fieldIdLabels → const int
fieldIdName → const int
fieldIdRows → const int
fieldIdStyleId → const int
fieldIdSubmitActionId → const int
fieldIdUpdateActionId → const int
fieldIdVariant → const int
teleportOpcode → const int
teleportVersion → const int