UIListBegin class

Constructors

UIListBegin({int elementId = 0, List<String> labels = const [], String styleId = '', UIListType type_ = UIListType.default_})
UIListBegin.fromJson(Map<String, dynamic> json)
factory
UIListBegin.fromReader(TeleportObjectReader reader)
factory
UIListBegin.fromTeleport(Uint8List data)
factory

Properties

elementId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String
getter/setter pair
type_ UIListType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdElementId → const int
fieldIdLabels → const int
fieldIdStyleId → const int
fieldIdType → const int
teleportOpcode → const int
teleportVersion → const int