UIPayload class

Constructors

UIPayload({String mimeType = '', List<int> value = const []})
UIPayload.fromJson(Map<String, dynamic> json)
factory
UIPayload.fromReader(TeleportObjectReader reader)
factory
UIPayload.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mimeType String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdMimeType → const int
fieldIdValue → const int
teleportVersion → const int