UIQS class

Constructors

UIQS({int elementId = 0, List<String> labels = const [], String styleId = '', String name = '', String eventActionId = '', Map<String, String> argumentsJson = const {}})
UIQS.fromJson(Map<String, dynamic> json)
factory
UIQS.fromReader(TeleportObjectReader reader)
factory
UIQS.fromTeleport(Uint8List data)
factory

Properties

argumentsJson Map<String, String>
getter/setter pair
elementId int
getter/setter pair
eventActionId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels List<String>
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdArgumentsJson → const int
fieldIdElementId → const int
fieldIdEventActionId → const int
fieldIdLabels → const int
fieldIdName → const int
fieldIdStyleId → const int
teleportOpcode → const int
teleportVersion → const int