UIText class
Constructors
-
UIText({int elementId = 0, List<
String> labels = const [], String styleId = '', String text = '', UITextType type_ = UITextType.normal, UIColor color = UIColor.default_}) -
UIText.fromJson(Map<
String, dynamic> json) -
factory
- UIText.fromReader(TeleportObjectReader reader)
-
factory
- UIText.fromTeleport(Uint8List data)
-
factory
Properties
- color ↔ UIColor
-
getter/setter pair
- elementId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleId ↔ String
-
getter/setter pair
- text ↔ String
-
getter/setter pair
- type_ ↔ UITextType
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdColor → const int
- fieldIdElementId → const int
- fieldIdLabels → const int
- fieldIdStyleId → const int
- fieldIdText → const int
- fieldIdType → const int
- teleportOpcode → const int
- teleportVersion → const int