UIVegaChart class
Constructors
-
UIVegaChart({int elementId = 0, List<
String> labels = const [], String styleId = '', String dataJson = '', String specJson = ''}) -
UIVegaChart.fromJson(Map<
String, dynamic> json) -
factory
- UIVegaChart.fromReader(TeleportObjectReader reader)
-
factory
- UIVegaChart.fromTeleport(Uint8List data)
-
factory
Properties
- dataJson ↔ String
-
getter/setter pair
- elementId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specJson ↔ String
-
getter/setter pair
- styleId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdDataJson → const int
- fieldIdElementId → const int
- fieldIdLabels → const int
- fieldIdSpecJson → const int
- fieldIdStyleId → const int
- teleportOpcode → const int
- teleportVersion → const int