UIStreamBegin class

Constructors

UIStreamBegin({String category = ''})
UIStreamBegin.fromJson(Map<String, dynamic> json)
factory
UIStreamBegin.fromReader(TeleportObjectReader reader)
factory
UIStreamBegin.fromTeleport(Uint8List data)
factory

Properties

category String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCategory → const int
teleportOpcode → const int
teleportVersion → const int