InvalidateVideoFrame class

Constructors

InvalidateVideoFrame({int frameNumber = 0, int timeStampInUs = 0})
InvalidateVideoFrame.fromJson(Map<String, dynamic> json)
factory
InvalidateVideoFrame.fromReader(TeleportObjectReader reader)
factory
InvalidateVideoFrame.fromTeleport(Uint8List data)
factory

Properties

frameNumber int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeStampInUs int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdFrameNumber → const int
fieldIdTimeStampInUs → const int
teleportOpcode → const int
teleportVersion → const int