VideoFrame class

Constructors

VideoFrame({List<int> data = const [], int frameNumber = 0, bool isKey = false, int timestampInUs = 0, int durationInUs = 0})
VideoFrame.fromJson(Map<String, dynamic> json)
factory
VideoFrame.fromReader(TeleportObjectReader reader)
factory
VideoFrame.fromTeleport(Uint8List data)
factory

Properties

data List<int>
getter/setter pair
durationInUs int
getter/setter pair
frameNumber int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isKey bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampInUs int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdData → const int
fieldIdDurationInUs → const int
fieldIdFrameNumber → const int
fieldIdIsKey → const int
fieldIdTimestampInUs → const int
teleportOpcode → const int
teleportVersion → const int