VideoStreamBegin class

Constructors

VideoStreamBegin({String streamId = '', String description = '', String sourceType = '', VideoCodec codec = VideoCodec.H264, String codecDetails = '', int width = 0, int height = 0, double framerate = 30.0, String? correlationId})
VideoStreamBegin.fromJson(Map<String, dynamic> json)
factory
VideoStreamBegin.fromReader(TeleportObjectReader reader)
factory
VideoStreamBegin.fromTeleport(Uint8List data)
factory

Properties

codec VideoCodec
getter/setter pair
codecDetails String
getter/setter pair
correlationId String?
getter/setter pair
description String
getter/setter pair
framerate double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType String
getter/setter pair
streamId String
getter/setter pair
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCodec → const int
fieldIdCodecDetails → const int
fieldIdCorrelationId → const int
fieldIdDescription → const int
fieldIdFramerate → const int
fieldIdHeight → const int
fieldIdSourceType → const int
fieldIdStreamId → const int
fieldIdWidth → const int
teleportOpcode → const int
teleportVersion → const int