WebRTCAnswer class

Constructors

WebRTCAnswer({String sdp = '', String iceServersJson = ''})
WebRTCAnswer.fromJson(Map<String, dynamic> json)
factory
WebRTCAnswer.fromReader(TeleportObjectReader reader)
factory
WebRTCAnswer.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
iceServersJson String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdp String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdIceServersJson → const int
fieldIdSdp → const int
teleportOpcode → const int
teleportVersion → const int