WebRTCAudioSegment class

Constructors

WebRTCAudioSegment({bool isStart = false, String? correlationId})
WebRTCAudioSegment.fromJson(Map<String, dynamic> json)
factory
WebRTCAudioSegment.fromReader(TeleportObjectReader reader)
factory
WebRTCAudioSegment.fromTeleport(Uint8List data)
factory

Properties

correlationId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isStart bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCorrelationId → const int
fieldIdIsStart → const int
teleportOpcode → const int
teleportVersion → const int