WebRTCIceCandidate class

Constructors

WebRTCIceCandidate({String candidate = '', String sdpMid = '', int sdpMLineIndex = 0})
WebRTCIceCandidate.fromJson(Map<String, dynamic> json)
factory
WebRTCIceCandidate.fromReader(TeleportObjectReader reader)
factory
WebRTCIceCandidate.fromTeleport(Uint8List data)
factory

Properties

candidate String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdpMid String
getter/setter pair
sdpMLineIndex int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCandidate → const int
fieldIdSdpMid → const int
fieldIdSdpMLineIndex → const int
teleportOpcode → const int
teleportVersion → const int