WebRTCOffer class

Constructors

WebRTCOffer({String sdp = '', Opcode opcodeGroupsFromServer = Opcode.NONE, Opcode opcodeGroupsToServer = Opcode.NONE, bool useAudioTrack = false, bool useVideoTrack = false, bool useDataChannel = false})
WebRTCOffer.fromJson(Map<String, dynamic> json)
factory
WebRTCOffer.fromReader(TeleportObjectReader reader)
factory
WebRTCOffer.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
opcodeGroupsFromServer Opcode
getter/setter pair
opcodeGroupsToServer Opcode
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdp String
getter/setter pair
useAudioTrack bool
getter/setter pair
useDataChannel bool
getter/setter pair
useVideoTrack bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited