WebRTCTrackMap class

Constructors

WebRTCTrackMap({String kind = '', int trackIndex = 0, int senderId = 0, int senderTrackId = 0, String streamId = '', String sourceType = '', bool active = true})
WebRTCTrackMap.fromJson(Map<String, dynamic> json)
factory
WebRTCTrackMap.fromReader(TeleportObjectReader reader)
factory
WebRTCTrackMap.fromTeleport(Uint8List data)
factory

Properties

active bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kind String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId int
getter/setter pair
senderTrackId int
getter/setter pair
sourceType String
getter/setter pair
streamId String
getter/setter pair
trackIndex int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdActive → const int
fieldIdKind → const int
fieldIdSenderId → const int
fieldIdSenderTrackId → const int
fieldIdSourceType → const int
fieldIdStreamId → const int
fieldIdTrackIndex → const int
teleportOpcode → const int
teleportVersion → const int