WebRTCVideoCapture class

Constructors

WebRTCVideoCapture({int senderIndex = 0, String? correlationId})
WebRTCVideoCapture.fromJson(Map<String, dynamic> json)
factory
WebRTCVideoCapture.fromReader(TeleportObjectReader reader)
factory
WebRTCVideoCapture.fromTeleport(Uint8List data)
factory

Properties

correlationId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderIndex int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCorrelationId → const int
fieldIdSenderIndex → const int
teleportOpcode → const int
teleportVersion → const int