ActionClassificationDetail class

Constructors

ActionClassificationDetail({String label = '', String originalCategory = '', bool isFlagged = false, double score = 0.0})
ActionClassificationDetail.fromJson(Map<String, dynamic> json)
factory
ActionClassificationDetail.fromReader(TeleportObjectReader reader)
factory
ActionClassificationDetail.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isFlagged bool
getter/setter pair
label String
getter/setter pair
originalCategory String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdIsFlagged → const int
fieldIdLabel → const int
fieldIdOriginalCategory → const int
fieldIdScore → const int
teleportVersion → const int