ActionCustomUserMessage class

Constructors

ActionCustomUserMessage({int? opcode, String? typeName, String? mimeType, String? jsonPayload, List<int>? binaryPayload})
ActionCustomUserMessage.fromJson(Map<String, dynamic> json)
factory
ActionCustomUserMessage.fromReader(TeleportObjectReader reader)
factory
ActionCustomUserMessage.fromTeleport(Uint8List data)
factory

Properties

binaryPayload List<int>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jsonPayload String?
getter/setter pair
mimeType String?
getter/setter pair
opcode int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdBinaryPayload → const int
fieldIdJsonPayload → const int
fieldIdMimeType → const int
fieldIdOpcode → const int
fieldIdTypeName → const int
teleportOpcode → const int
teleportVersion → const int