ActionFileUploadBegin class
Constructors
- ActionFileUploadBegin({String actionId = '', String fileName = '', String mime = '', int byteCount = 0, bool checkHash = false, String hash = ''})
-
ActionFileUploadBegin.fromJson(Map<
String, dynamic> json) -
factory
- ActionFileUploadBegin.fromReader(TeleportObjectReader reader)
-
factory
- ActionFileUploadBegin.fromTeleport(Uint8List data)
-
factory
Properties
- actionId ↔ String
-
getter/setter pair
- byteCount ↔ int
-
getter/setter pair
- checkHash ↔ bool
-
getter/setter pair
- fileName ↔ String
-
getter/setter pair
- hash ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mime ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdActionId → const int
- fieldIdByteCount → const int
- fieldIdCheckHash → const int
- fieldIdFileName → const int
- fieldIdHash → const int
- fieldIdMime → const int
- teleportOpcode → const int
- teleportVersion → const int