ActionFileUploadPreStart2 class

Constructors

ActionFileUploadPreStart2({String uploadId = '', String uploadActionId = '', String fileName = '', String mime = '', int byteCount = 0})
ActionFileUploadPreStart2.fromJson(Map<String, dynamic> json)
factory
ActionFileUploadPreStart2.fromReader(TeleportObjectReader reader)
factory
ActionFileUploadPreStart2.fromTeleport(Uint8List data)
factory

Properties

byteCount int
getter/setter pair
fileName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mime String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uploadActionId String
getter/setter pair
uploadId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdByteCount → const int
fieldIdFileName → const int
fieldIdMime → const int
fieldIdUploadActionId → const int
fieldIdUploadId → const int
teleportOpcode → const int
teleportVersion → const int