ActionTriggerCron class

Constructors

ActionTriggerCron({String functionName = '', String schedule = '', String fireTimeUtc = ''})
ActionTriggerCron.fromJson(Map<String, dynamic> json)
factory
ActionTriggerCron.fromReader(TeleportObjectReader reader)
factory
ActionTriggerCron.fromTeleport(Uint8List data)
factory

Properties

fireTimeUtc String
getter/setter pair
functionName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdFireTimeUtc → const int
fieldIdFunctionName → const int
fieldIdSchedule → const int
teleportOpcode → const int
teleportVersion → const int