AnalyticsEventsItem class

Constructors

AnalyticsEventsItem({String time = '', String eventName = '', String message = '', String parameters = ''})
AnalyticsEventsItem.fromJson(Map<String, dynamic> json)
factory
AnalyticsEventsItem.fromReader(TeleportObjectReader reader)
factory
AnalyticsEventsItem.fromTeleport(Uint8List data)
factory

Properties

eventName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pair
parameters String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdEventName → const int
fieldIdMessage → const int
fieldIdParameters → const int
fieldIdTime → const int
teleportVersion → const int