AnalyticsIkonRelayServerStats class
Constructors
- AnalyticsIkonRelayServerStats({String time = '', int agentCount = 0, int tcpTunnelCount = 0, int udpTunnelCount = 0, int tcpConnectionCount = 0, double cpuUsagePercentage = 0.0, double processMemoryUsedMb = 0.0, double managedMemoryUsedMb = 0.0, String memoryInfo = ''})
-
AnalyticsIkonRelayServerStats.fromJson(Map<
String, dynamic> json) -
factory
- AnalyticsIkonRelayServerStats.fromReader(TeleportObjectReader reader)
-
factory
- AnalyticsIkonRelayServerStats.fromTeleport(Uint8List data)
-
factory
Properties
- agentCount ↔ int
-
getter/setter pair
- cpuUsagePercentage ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- managedMemoryUsedMb ↔ double
-
getter/setter pair
- memoryInfo ↔ String
-
getter/setter pair
- processMemoryUsedMb ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tcpConnectionCount ↔ int
-
getter/setter pair
- tcpTunnelCount ↔ int
-
getter/setter pair
- time ↔ String
-
getter/setter pair
- udpTunnelCount ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdAgentCount → const int
- fieldIdCpuUsagePercentage → const int
- fieldIdManagedMemoryUsedMb → const int
- fieldIdMemoryInfo → const int
- fieldIdProcessMemoryUsedMb → const int
- fieldIdTcpConnectionCount → const int
- fieldIdTcpTunnelCount → const int
- fieldIdTime → const int
- fieldIdUdpTunnelCount → const int
- teleportOpcode → const int
- teleportVersion → const int