AnalyticsLogsItem class

Constructors

AnalyticsLogsItem({String time = '', int type_ = 0, String message = '', String parameters = ''})
AnalyticsLogsItem.fromJson(Map<String, dynamic> json)
factory
AnalyticsLogsItem.fromReader(TeleportObjectReader reader)
factory
AnalyticsLogsItem.fromTeleport(Uint8List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pair
parameters String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
getter/setter pair
type_ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdMessage → const int
fieldIdParameters → const int
fieldIdTime → const int
fieldIdType → const int
teleportVersion → const int