AnalyticsProcessingUpdate class
Constructors
-
AnalyticsProcessingUpdate({String processingId = '', int totalRuns = 0, int totalItems = 0, int totalPages = 0, int totalRetries = 0, int totalFailures = 0, String startedAt = '', double elapsedSeconds = 0.0, Map<
String, double> usages = const {}, int runsRemaining = 0, int itemsRemaining = 0, double estimatedTimeLeftSecondsRuns = 0.0, double estimatedTimeLeftSecondsItems = 0.0}) -
AnalyticsProcessingUpdate.fromJson(Map<
String, dynamic> json) -
factory
- AnalyticsProcessingUpdate.fromReader(TeleportObjectReader reader)
-
factory
- AnalyticsProcessingUpdate.fromTeleport(Uint8List data)
-
factory
Properties
- elapsedSeconds ↔ double
-
getter/setter pair
- estimatedTimeLeftSecondsItems ↔ double
-
getter/setter pair
- estimatedTimeLeftSecondsRuns ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemsRemaining ↔ int
-
getter/setter pair
- processingId ↔ String
-
getter/setter pair
- runsRemaining ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt ↔ String
-
getter/setter pair
- totalFailures ↔ int
-
getter/setter pair
- totalItems ↔ int
-
getter/setter pair
- totalPages ↔ int
-
getter/setter pair
- totalRetries ↔ int
-
getter/setter pair
- totalRuns ↔ int
-
getter/setter pair
-
usages
↔ Map<
String, double> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdElapsedSeconds → const int
- fieldIdEstimatedTimeLeftSecondsItems → const int
- fieldIdEstimatedTimeLeftSecondsRuns → const int
- fieldIdItemsRemaining → const int
- fieldIdProcessingId → const int
- fieldIdRunsRemaining → const int
- fieldIdStartedAt → const int
- fieldIdTotalFailures → const int
- fieldIdTotalItems → const int
- fieldIdTotalPages → const int
- fieldIdTotalRetries → const int
- fieldIdTotalRuns → const int
- fieldIdUsages → const int
- teleportOpcode → const int
- teleportVersion → const int