AnalyticsReactiveProcessingUpdate class

Constructors

AnalyticsReactiveProcessingUpdate({String processingId = '', String startedAt = '', double elapsedSeconds = 0.0, int inputItemCount = 0, int inputItemCacheHits = 0, int inputItemCacheMiss = 0, int processedItemCount = 0, int processedItemCacheHits = 0, int processedItemCacheMiss = 0, int outputItemCount = 0, int outputItemCacheHits = 0, int outputItemCacheMiss = 0, int invalidItemCount = 0, int duplicateItemCount = 0, int processRetryCount = 0, int processFailureCount = 0, int warningLogCount = 0, int errorLogCount = 0, bool hasCompleted = false, bool hasFaulted = false, bool wasCancelled = false, Map<String, double> usages = const {}})
AnalyticsReactiveProcessingUpdate.fromJson(Map<String, dynamic> json)
factory
AnalyticsReactiveProcessingUpdate.fromReader(TeleportObjectReader reader)
factory
AnalyticsReactiveProcessingUpdate.fromTeleport(Uint8List data)
factory

Properties

duplicateItemCount int
getter/setter pair
elapsedSeconds double
getter/setter pair
errorLogCount int
getter/setter pair
hasCompleted bool
getter/setter pair
hasFaulted bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputItemCacheHits int
getter/setter pair
inputItemCacheMiss int
getter/setter pair
inputItemCount int
getter/setter pair
invalidItemCount int
getter/setter pair
outputItemCacheHits int
getter/setter pair
outputItemCacheMiss int
getter/setter pair
outputItemCount int
getter/setter pair
processedItemCacheHits int
getter/setter pair
processedItemCacheMiss int
getter/setter pair
processedItemCount int
getter/setter pair
processFailureCount int
getter/setter pair
processingId String
getter/setter pair
processRetryCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt String
getter/setter pair
usages Map<String, double>
getter/setter pair
warningLogCount int
getter/setter pair
wasCancelled bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited