AudioFrame class

Constructors

AudioFrame({List<int> data = const [], bool isKey = false, bool isLast = false, int timestampInUs = 0, int durationInUs = 0, bool isFirst = false, int totalDurationInUs = 0, double volume = 0.0, int volumeSampleCount = 0})
AudioFrame.fromJson(Map<String, dynamic> json)
factory
AudioFrame.fromReader(TeleportObjectReader reader)
factory
AudioFrame.fromTeleport(Uint8List data)
factory

Properties

data List<int>
getter/setter pair
durationInUs int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isFirst bool
getter/setter pair
isKey bool
getter/setter pair
isLast bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampInUs int
getter/setter pair
totalDurationInUs int
getter/setter pair
volume double
getter/setter pair
volumeSampleCount int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdData → const int
fieldIdDurationInUs → const int
fieldIdIsFirst → const int
fieldIdIsKey → const int
fieldIdIsLast → const int
fieldIdTimestampInUs → const int
fieldIdTotalDurationInUs → const int
fieldIdVolume → const int
fieldIdVolumeSampleCount → const int
teleportOpcode → const int
teleportVersion → const int