AuthResponse class
Constructors
-
AuthResponse({Context? clientContext, Context? serverContext, String certHash = '', List<
Entrypoint> entrypoints = const [], Map<String, bool> featureFlags = const {}, String spaceId = '', String channelId = '', String channelInstanceId = '', String primaryUserId = '', String serverSessionId = '', int keepaliveTimeoutMs = 0, int serverCapability = 0}) -
AuthResponse.fromJson(Map<
String, dynamic> json) -
factory
- AuthResponse.fromReader(TeleportObjectReader reader)
-
factory
- AuthResponse.fromTeleport(Uint8List data)
-
factory
Properties
- certHash ↔ String
-
getter/setter pair
- channelId ↔ String
-
getter/setter pair
- channelInstanceId ↔ String
-
getter/setter pair
- clientContext ↔ Context?
-
getter/setter pair
-
entrypoints
↔ List<
Entrypoint> -
getter/setter pair
-
featureFlags
↔ Map<
String, bool> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepaliveTimeoutMs ↔ int
-
getter/setter pair
- primaryUserId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverCapability ↔ int
-
getter/setter pair
- serverContext ↔ Context?
-
getter/setter pair
- serverSessionId ↔ String
-
getter/setter pair
- spaceId ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdCertHash → const int
- fieldIdChannelId → const int
- fieldIdChannelInstanceId → const int
- fieldIdClientContext → const int
- fieldIdEntrypoints → const int
- fieldIdFeatureFlags → const int
- fieldIdKeepaliveTimeoutMs → const int
- fieldIdPrimaryUserId → const int
- fieldIdServerCapability → const int
- fieldIdServerContext → const int
- fieldIdServerSessionId → const int
- fieldIdSpaceId → const int
- teleportOpcode → const int
- teleportVersion → const int