AuthTicket class
Constructors
- AuthTicket({String host = '', int httpsPort = 0, int tcpPort = 0, String secret = '', Opcode opcodeGroupsFromServer = Opcode.NONE, Opcode opcodeGroupsToServer = Opcode.NONE, Context? clientContext, int tlsPort = 0, int udpPort = 0, int udpDtlsPort = 0})
-
AuthTicket.fromJson(Map<
String, dynamic> json) -
factory
- AuthTicket.fromReader(TeleportObjectReader reader)
-
factory
- AuthTicket.fromTeleport(Uint8List data)
-
factory
Properties
- clientContext ↔ Context?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String
-
getter/setter pair
- httpsPort ↔ int
-
getter/setter pair
- opcodeGroupsFromServer ↔ Opcode
-
getter/setter pair
- opcodeGroupsToServer ↔ Opcode
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret ↔ String
-
getter/setter pair
- tcpPort ↔ int
-
getter/setter pair
- tlsPort ↔ int
-
getter/setter pair
- udpDtlsPort ↔ int
-
getter/setter pair
- udpPort ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdClientContext → const int
- fieldIdHost → const int
- fieldIdHttpsPort → const int
- fieldIdOpcodeGroupsFromServer → const int
- fieldIdOpcodeGroupsToServer → const int
- fieldIdSecret → const int
- fieldIdTcpPort → const int
- fieldIdTlsPort → const int
- fieldIdUdpDtlsPort → const int
- fieldIdUdpPort → const int
- teleportOpcode → const int
- teleportVersion → const int