ConnectToken class
Constructors
-
ConnectToken({String serverSessionId = '', ContextType contextType = ContextType.unknown, UserType userType = UserType.unknown, PayloadType payloadType = PayloadType.unknown, bool isInternal = false, String description = '', String userId = '', String deviceId = '', String productId = '', String versionId = '', String installId = '', String locale = '', Opcode opcodeGroupsFromServer = Opcode.NONE, Opcode opcodeGroupsToServer = Opcode.NONE, int protocolVersion = 0, bool hasInput = false, String channelLocale = '', String embeddedSpaceId = '', String authSessionId = '', bool receiveAllMessages = false, String userAgent = '', ClientType clientType = ClientType.unknown, Map<
String, String> parameters = const {}, SdkType sdkType = SdkType.unknown, int viewportWidth = 0, int viewportHeight = 0, String theme = '', String timezone = '', bool isTouchDevice = false, String initialPath = '', StyleFormat styleFormat = StyleFormat.css}) -
ConnectToken.fromJson(Map<
String, dynamic> json) -
factory
- ConnectToken.fromReader(TeleportObjectReader reader)
-
factory
- ConnectToken.fromTeleport(Uint8List data)
-
factory
Properties
- authSessionId ↔ String
-
getter/setter pair
- channelLocale ↔ String
-
getter/setter pair
- clientType ↔ ClientType
-
getter/setter pair
- contextType ↔ ContextType
-
getter/setter pair
- description ↔ String
-
getter/setter pair
- deviceId ↔ String
-
getter/setter pair
- embeddedSpaceId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInput ↔ bool
-
getter/setter pair
- initialPath ↔ String
-
getter/setter pair
- installId ↔ String
-
getter/setter pair
- isInternal ↔ bool
-
getter/setter pair
- isTouchDevice ↔ bool
-
getter/setter pair
- locale ↔ String
-
getter/setter pair
- opcodeGroupsFromServer ↔ Opcode
-
getter/setter pair
- opcodeGroupsToServer ↔ Opcode
-
getter/setter pair
-
parameters
↔ Map<
String, String> -
getter/setter pair
- payloadType ↔ PayloadType
-
getter/setter pair
- productId ↔ String
-
getter/setter pair
- protocolVersion ↔ int
-
getter/setter pair
- receiveAllMessages ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkType ↔ SdkType
-
getter/setter pair
- serverSessionId ↔ String
-
getter/setter pair
- styleFormat ↔ StyleFormat
-
getter/setter pair
- theme ↔ String
-
getter/setter pair
- timezone ↔ String
-
getter/setter pair
- userAgent ↔ String
-
getter/setter pair
- userId ↔ String
-
getter/setter pair
- userType ↔ UserType
-
getter/setter pair
- versionId ↔ String
-
getter/setter pair
- viewportHeight ↔ int
-
getter/setter pair
- viewportWidth ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdAuthSessionId → const int
- fieldIdChannelLocale → const int
- fieldIdClientType → const int
- fieldIdContextType → const int
- fieldIdDescription → const int
- fieldIdDeviceId → const int
- fieldIdEmbeddedSpaceId → const int
- fieldIdHasInput → const int
- fieldIdInitialPath → const int
- fieldIdInstallId → const int
- fieldIdIsInternal → const int
- fieldIdIsTouchDevice → const int
- fieldIdLocale → const int
- fieldIdOpcodeGroupsFromServer → const int
- fieldIdOpcodeGroupsToServer → const int
- fieldIdParameters → const int
- fieldIdPayloadType → const int
- fieldIdProductId → const int
- fieldIdProtocolVersion → const int
- fieldIdReceiveAllMessages → const int
- fieldIdSdkType → const int
- fieldIdServerSessionId → const int
- fieldIdStyleFormat → const int
- fieldIdTheme → const int
- fieldIdTimezone → const int
- fieldIdUserAgent → const int
- fieldIdUserId → const int
- fieldIdUserType → const int
- fieldIdVersionId → const int
- fieldIdViewportHeight → const int
- fieldIdViewportWidth → const int
- teleportVersion → const int