Entrypoint class
Constructors
-
Entrypoint({EntrypointType type_ = EntrypointType.none, String uri = '', Opcode opcodeGroupsFromServer = Opcode.NONE, Opcode opcodeGroupsToServer = Opcode.NONE, int priority = 0, String description = '', List<
int> authTicket = const [], bool isUnreliable = false}) -
Entrypoint.fromJson(Map<
String, dynamic> json) -
factory
- Entrypoint.fromReader(TeleportObjectReader reader)
-
factory
- Entrypoint.fromTeleport(Uint8List data)
-
factory
Properties
-
authTicket
↔ List<
int> -
getter/setter pair
- description ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUnreliable ↔ bool
-
getter/setter pair
- opcodeGroupsFromServer ↔ Opcode
-
getter/setter pair
- opcodeGroupsToServer ↔ Opcode
-
getter/setter pair
- priority ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type_ ↔ EntrypointType
-
getter/setter pair
- uri ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdAuthTicket → const int
- fieldIdDescription → const int
- fieldIdIsUnreliable → const int
- fieldIdOpcodeGroupsFromServer → const int
- fieldIdOpcodeGroupsToServer → const int
- fieldIdPriority → const int
- fieldIdType → const int
- fieldIdUri → const int
- teleportVersion → const int