Context class

Constructors

Context({ContextType contextType = ContextType.unknown, UserType userType = UserType.unknown, PayloadType payloadType = PayloadType.unknown, String description = '', String userId = '', String deviceId = '', String productId = '', String versionId = '', String installId = '', String locale = '', int sessionId = -1, bool isInternal = false, bool isSnapshot = false, bool isReady = false, bool hasInput = false, String channelLocale = '', String embeddedSpaceId = '', String authSessionId = '', bool receiveAllMessages = false, int preciseJoinedAt = 0, String userAgent = '', ClientType clientType = ClientType.unknown, String uniqueSessionId = '', Map<String, String> parameters = const {}, SdkType sdkType = SdkType.unknown, int sdkCapability = 0, int viewportWidth = 0, int viewportHeight = 0, String theme = '', String timezone = '', bool isTouchDevice = false, String initialPath = '', StyleFormat styleFormat = StyleFormat.css, bool supportsCompression = true, bool isSoftDisconnected = false, int softDisconnectAt = 0})
Context.fromJson(Map<String, dynamic> json)
factory
Context.fromReader(TeleportObjectReader reader)
factory
Context.fromTeleport(Uint8List data)
factory

Properties

authSessionId String
getter/setter pair
channelLocale String
getter/setter pair
clientType ClientType
getter/setter pair
contextType ContextType
getter/setter pair
description String
getter/setter pair
deviceId String
getter/setter pair
embeddedSpaceId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasInput bool
getter/setter pair
initialPath String
getter/setter pair
installId String
getter/setter pair
isInternal bool
getter/setter pair
isReady bool
getter/setter pair
isSnapshot bool
getter/setter pair
isSoftDisconnected bool
getter/setter pair
isTouchDevice bool
getter/setter pair
locale String
getter/setter pair
parameters Map<String, String>
getter/setter pair
payloadType PayloadType
getter/setter pair
preciseJoinedAt int
getter/setter pair
productId String
getter/setter pair
receiveAllMessages bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkCapability int
getter/setter pair
sdkType SdkType
getter/setter pair
sessionId int
getter/setter pair
softDisconnectAt int
getter/setter pair
styleFormat StyleFormat
getter/setter pair
supportsCompression bool
getter/setter pair
theme String
getter/setter pair
timezone String
getter/setter pair
uniqueSessionId String
getter/setter pair
userAgent String
getter/setter pair
userId String
getter/setter pair
userType UserType
getter/setter pair
versionId String
getter/setter pair
viewportHeight int
getter/setter pair
viewportWidth int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited