UIElementLabels class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blur → const String
- chatMessage → const String
- disabled → const String
- imageAvatar → const String
- markdown → const String
- sizeExtraSmall → const String
- sizeFitContent → const String
- sizeFullWidth → const String
- sizeLarge → const String
- sizeMedium → const String
- sizeSmall → const String
- wrap → const String