ActionFunctionCall class
Constructors
-
ActionFunctionCall({String functionId = '', String callId = '', String instanceId = '', String functionName = '', List<
FunctionParameter> parameters = const [], List<ScopeEntry> scopes = const [], String version = '', List<UserCredentialEntry> userCredentials = const []}) -
ActionFunctionCall.fromJson(Map<
String, dynamic> json) -
factory
- ActionFunctionCall.fromReader(TeleportObjectReader reader)
-
factory
- ActionFunctionCall.fromTeleport(Uint8List data)
-
factory
Properties
- callId ↔ String
-
getter/setter pair
- functionId ↔ String
-
getter/setter pair
- functionName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceId ↔ String
-
getter/setter pair
-
parameters
↔ List<
FunctionParameter> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
↔ List<
ScopeEntry> -
getter/setter pair
-
userCredentials
↔ List<
UserCredentialEntry> -
getter/setter pair
- version ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdCallId → const int
- fieldIdFunctionId → const int
- fieldIdFunctionName → const int
- fieldIdInstanceId → const int
- fieldIdParameters → const int
- fieldIdScopes → const int
- fieldIdUserCredentials → const int
- fieldIdVersion → const int
- teleportOpcode → const int
- teleportVersion → const int