ActionFunctionError class

Constructors

ActionFunctionError({String callId = '', String instanceId = '', String errorMessage = '', String errorTypeName = '', String stackTrace = '', String errorCode = ''})
ActionFunctionError.fromJson(Map<String, dynamic> json)
factory
ActionFunctionError.fromReader(TeleportObjectReader reader)
factory
ActionFunctionError.fromTeleport(Uint8List data)
factory

Properties

callId String
getter/setter pair
errorCode String
getter/setter pair
errorMessage String
getter/setter pair
errorTypeName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdCallId → const int
fieldIdErrorCode → const int
fieldIdErrorMessage → const int
fieldIdErrorTypeName → const int
fieldIdInstanceId → const int
fieldIdStackTrace → const int
teleportOpcode → const int
teleportVersion → const int