ActionFunctionRegister class
Constructors
-
ActionFunctionRegister({String functionId = '', String functionName = '', List<
FunctionRegisterParameter> parameters = const [], String resultTypeName = '', bool isEnumerable = false, String enumerableItemTypeName = '', bool isCancellable = false, String description = '', bool llmInlineResult = false, bool llmCallOnlyOnce = false, bool requiresInstance = false, List<String> versions = const []}) -
ActionFunctionRegister.fromJson(Map<
String, dynamic> json) -
factory
- ActionFunctionRegister.fromReader(TeleportObjectReader reader)
-
factory
- ActionFunctionRegister.fromTeleport(Uint8List data)
-
factory
Properties
- description ↔ String
-
getter/setter pair
- enumerableItemTypeName ↔ String
-
getter/setter pair
- functionId ↔ String
-
getter/setter pair
- functionName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancellable ↔ bool
-
getter/setter pair
- isEnumerable ↔ bool
-
getter/setter pair
- llmCallOnlyOnce ↔ bool
-
getter/setter pair
- llmInlineResult ↔ bool
-
getter/setter pair
-
parameters
↔ List<
FunctionRegisterParameter> -
getter/setter pair
- requiresInstance ↔ bool
-
getter/setter pair
- resultTypeName ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
versions
↔ List<
String> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdDescription → const int
- fieldIdEnumerableItemTypeName → const int
- fieldIdFunctionId → const int
- fieldIdFunctionName → const int
- fieldIdIsCancellable → const int
- fieldIdIsEnumerable → const int
- fieldIdLlmCallOnlyOnce → const int
- fieldIdLlmInlineResult → const int
- fieldIdParameters → const int
- fieldIdRequiresInstance → const int
- fieldIdResultTypeName → const int
- fieldIdVersions → const int
- teleportOpcode → const int
- teleportVersion → const int