AudioStreamState class

Constructors

AudioStreamState({String streamId = '', int clientSessionId = 0, int trackId = 0, AudioStreamBegin? info})
AudioStreamState.fromJson(Map<String, dynamic> json)
factory
AudioStreamState.fromReader(TeleportObjectReader reader)
factory
AudioStreamState.fromTeleport(Uint8List data)
factory

Properties

clientSessionId int
Session ID of the client sending this stream
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info AudioStreamBegin?
Stream configuration including codec, sample rate, and channels
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String
Unique identifier for this stream
getter/setter pair
trackId int
Track identifier within the client
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
toTeleport() Uint8List
writeTo(TeleportObjectWriter scope) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdClientSessionId → const int
fieldIdInfo → const int
fieldIdStreamId → const int
fieldIdTrackId → const int
teleportVersion → const int