GlobalState class
Constructors
-
GlobalState({Map<
int, Context> clients = const {}, Map<int, List< functions = const {}, Map<ActionFunctionRegister> >String, UIStreamState> uIStreams = const {}, Map<String, AudioStreamState> audioStreams = const {}, Map<String, VideoStreamState> videoStreams = const {}, Map<String, TrackingStreamState> trackingStreams = const {}, String spaceId = '', String channelId = '', String serverSessionId = '', String sessionHash = '', String channelUrl = '', String sessionChannelUrl = '', String firstUserId = '', String primaryUserId = '', String organisationName = '', String spaceName = '', String channelName = '', ServerRunType serverRunType = ServerRunType.local, AppSourceType appSourceType = AppSourceType.bundle, bool publicAccess = false, bool debugMode = false}) -
GlobalState.fromJson(Map<
String, dynamic> json) -
factory
- GlobalState.fromReader(TeleportObjectReader reader)
-
factory
- GlobalState.fromTeleport(Uint8List data)
-
factory
Properties
- appSourceType ↔ AppSourceType
-
getter/setter pair
-
audioStreams
↔ Map<
String, AudioStreamState> -
getter/setter pair
- channelId ↔ String
-
getter/setter pair
- channelName ↔ String
-
getter/setter pair
- channelUrl ↔ String
-
getter/setter pair
-
clients
↔ Map<
int, Context> -
getter/setter pair
- debugMode ↔ bool
-
getter/setter pair
- firstUserId ↔ String
-
getter/setter pair
-
functions
↔ Map<
int, List< ActionFunctionRegister> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- organisationName ↔ String
-
getter/setter pair
- primaryUserId ↔ String
-
getter/setter pair
- publicAccess ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverRunType ↔ ServerRunType
-
getter/setter pair
- serverSessionId ↔ String
-
getter/setter pair
- sessionChannelUrl ↔ String
-
getter/setter pair
- sessionHash ↔ String
-
getter/setter pair
- spaceId ↔ String
-
getter/setter pair
- spaceName ↔ String
-
getter/setter pair
-
trackingStreams
↔ Map<
String, TrackingStreamState> -
getter/setter pair
-
uIStreams
↔ Map<
String, UIStreamState> -
getter/setter pair
-
videoStreams
↔ Map<
String, VideoStreamState> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdAppSourceType → const int
- fieldIdAudioStreams → const int
- fieldIdChannelId → const int
- fieldIdChannelName → const int
- fieldIdChannelUrl → const int
- fieldIdClients → const int
- fieldIdDebugMode → const int
- fieldIdFirstUserId → const int
- fieldIdFunctions → const int
- fieldIdOrganisationName → const int
- fieldIdPrimaryUserId → const int
- fieldIdPublicAccess → const int
- fieldIdServerRunType → const int
- fieldIdServerSessionId → const int
- fieldIdSessionChannelUrl → const int
- fieldIdSessionHash → const int
- fieldIdSpaceId → const int
- fieldIdSpaceName → const int
- fieldIdTrackingStreams → const int
- fieldIdUIStreams → const int
- fieldIdVideoStreams → const int
- teleportOpcode → const int
- teleportVersion → const int