appSessionId property
Unique identifier of the app session this server is serving — the session's business identity, stable across the servers that run it. Empty outside a cloud run.
Implementation
String appSessionId;
Unique identifier of the app session this server is serving — the session's business identity, stable across the servers that run it. Empty outside a cloud run.
String appSessionId;