ServerInit class
Constructors
-
ServerInit({String ikonBackendUrl = '', String ikonBackendToken = '', String spaceId = '', String channelId = '', List<
ServerPluginInit> plugins = const [], String primaryUserId = '', String channelInstanceId = '', String channelUrl = '', List<ServerExtensionInit> extensions = const [], Map<String, String> dynamicConfigObsolete = const {}, String organisationName = '', String spaceName = '', String channelName = '', String dynamicConfigJsonContent = '', String spaceGitRepositoryUrl = '', String sessionId = '', String legacyChannelCode = '', bool disableLegacyDefaultExtensions = false, Map<String, String> sessionIdentity = const {}, List<ServerInitEndpointRequest> endpointRequests = const [], int frontendPort = 0, AppSourceType appSourceType = AppSourceType.bundle, bool debugMode = false, List<ServerInitDatabaseConnectionInfo> databaseConnectionInfos = const [], String runTarget = ''}) -
ServerInit.fromJson(Map<
String, dynamic> json) -
factory
- ServerInit.fromReader(TeleportObjectReader reader)
-
factory
- ServerInit.fromTeleport(Uint8List data)
-
factory
Properties
- appSourceType ↔ AppSourceType
-
getter/setter pair
- channelId ↔ String
-
getter/setter pair
- channelInstanceId ↔ String
-
getter/setter pair
- channelName ↔ String
-
getter/setter pair
- channelUrl ↔ String
-
getter/setter pair
-
databaseConnectionInfos
↔ List<
ServerInitDatabaseConnectionInfo> -
getter/setter pair
- debugMode ↔ bool
-
getter/setter pair
- disableLegacyDefaultExtensions ↔ bool
-
getter/setter pair
- dynamicConfigJsonContent ↔ String
-
getter/setter pair
-
dynamicConfigObsolete
↔ Map<
String, String> -
getter/setter pair
-
endpointRequests
↔ List<
ServerInitEndpointRequest> -
getter/setter pair
-
extensions
↔ List<
ServerExtensionInit> -
getter/setter pair
- frontendPort ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ikonBackendToken ↔ String
-
getter/setter pair
- ikonBackendUrl ↔ String
-
getter/setter pair
- legacyChannelCode ↔ String
-
getter/setter pair
- organisationName ↔ String
-
getter/setter pair
-
plugins
↔ List<
ServerPluginInit> -
getter/setter pair
- primaryUserId ↔ String
-
getter/setter pair
- runTarget ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId ↔ String
-
getter/setter pair
-
sessionIdentity
↔ Map<
String, String> -
getter/setter pair
- spaceGitRepositoryUrl ↔ String
-
getter/setter pair
- spaceId ↔ String
-
getter/setter pair
- spaceName ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdAppSourceType → const int
- fieldIdChannelId → const int
- fieldIdChannelInstanceId → const int
- fieldIdChannelName → const int
- fieldIdChannelUrl → const int
- fieldIdDatabaseConnectionInfos → const int
- fieldIdDebugMode → const int
- fieldIdDisableLegacyDefaultExtensions → const int
- fieldIdDynamicConfigJsonContent → const int
- fieldIdDynamicConfigObsolete → const int
- fieldIdEndpointRequests → const int
- fieldIdExtensions → const int
- fieldIdFrontendPort → const int
- fieldIdIkonBackendToken → const int
- fieldIdIkonBackendUrl → const int
- fieldIdLegacyChannelCode → const int
- fieldIdOrganisationName → const int
- fieldIdPlugins → const int
- fieldIdPrimaryUserId → const int
- fieldIdRunTarget → const int
- fieldIdSessionId → const int
- fieldIdSessionIdentity → const int
- fieldIdSpaceGitRepositoryUrl → const int
- fieldIdSpaceId → const int
- fieldIdSpaceName → const int
- teleportOpcode → const int
- teleportVersion → const int