RelayAgentAuthResult class
Constructors
- RelayAgentAuthResult({bool success = false, String publicHost = '', double heartbeatIntervalSeconds = 0.0})
-
RelayAgentAuthResult.fromJson(Map<
String, dynamic> json) -
factory
- RelayAgentAuthResult.fromReader(TeleportObjectReader reader)
-
factory
- RelayAgentAuthResult.fromTeleport(Uint8List data)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartbeatIntervalSeconds ↔ double
-
getter/setter pair
- publicHost ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success ↔ bool
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdHeartbeatIntervalSeconds → const int
- fieldIdPublicHost → const int
- fieldIdSuccess → const int
- teleportOpcode → const int
- teleportVersion → const int