RelayTunnelAdded class
Constructors
- RelayTunnelAdded({int requestId = 0, bool success = false, String errorMessage = '', int tunnelId = 0, int publicPort = 0})
-
RelayTunnelAdded.fromJson(Map<
String, dynamic> json) -
factory
- RelayTunnelAdded.fromReader(TeleportObjectReader reader)
-
factory
- RelayTunnelAdded.fromTeleport(Uint8List data)
-
factory
Properties
- errorMessage ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicPort ↔ int
-
getter/setter pair
- requestId ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success ↔ bool
-
getter/setter pair
- tunnelId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdErrorMessage → const int
- fieldIdPublicPort → const int
- fieldIdRequestId → const int
- fieldIdSuccess → const int
- fieldIdTunnelId → const int
- teleportOpcode → const int
- teleportVersion → const int