RelayUdpData class
Constructors
-
RelayUdpData({int tunnelId = 0, String sourceAddress = '', int sourcePort = 0, List<
int> data = const []}) -
RelayUdpData.fromJson(Map<
String, dynamic> json) -
factory
- RelayUdpData.fromReader(TeleportObjectReader reader)
-
factory
- RelayUdpData.fromTeleport(Uint8List data)
-
factory
Properties
-
data
↔ List<
int> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceAddress ↔ String
-
getter/setter pair
- sourcePort ↔ int
-
getter/setter pair
- tunnelId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdData → const int
- fieldIdSourceAddress → const int
- fieldIdSourcePort → const int
- fieldIdTunnelId → const int
- teleportOpcode → const int
- teleportVersion → const int