TrackingFrame class
Constructors
-
TrackingFrame({int timestampInUs = 0, int durationInUs = 0, List<
double> faceBlendshapes = const [], List<double> faceTransformationMatrix = const []}) -
TrackingFrame.fromJson(Map<
String, dynamic> json) -
factory
- TrackingFrame.fromReader(TeleportObjectReader reader)
-
factory
- TrackingFrame.fromTeleport(Uint8List data)
-
factory
Properties
- durationInUs ↔ int
-
getter/setter pair
-
faceBlendshapes
↔ List<
double> -
getter/setter pair
-
faceTransformationMatrix
↔ List<
double> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestampInUs ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fieldIdDurationInUs → const int
- fieldIdFaceBlendshapes → const int
- fieldIdFaceTransformationMatrix → const int
- fieldIdTimestampInUs → const int
- teleportOpcode → const int
- teleportVersion → const int