UIHeader class

Constructors

UIHeader({int elementId = 0, List<String> labels = const [], String styleId = '', String text = '', String subText = '', UIHeaderLevel level = UIHeaderLevel.default_})
UIHeader.fromJson(Map<String, dynamic> json)
factory
UIHeader.fromReader(TeleportObjectReader reader)
factory
UIHeader.fromTeleport(Uint8List data)
factory

Properties

elementId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels List<String>
getter/setter pair
level UIHeaderLevel
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String
getter/setter pair
subText String
getter/setter pair
text String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fieldIdElementId → const int
fieldIdLabels → const int
fieldIdLevel → const int
fieldIdStyleId → const int
fieldIdSubText → const int
fieldIdText → const int
teleportOpcode → const int
teleportVersion → const int